# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKImageComparePython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkCheckerBoardImageFilterPython
else:
    import _itkCheckerBoardImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkFixedArrayPython
import itk.pyBasePython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkCovariantVectorPython
import itk.vnl_vector_refPython
import itk.stdcomplexPython
import itk.vnl_vectorPython
import itk.vnl_matrixPython
import itk.itkVectorPython
import itk.vnl_matrix_fixedPython
import itk.itkPointPython
import itk.itkImagePython
import itk.itkImageRegionPython
import itk.itkIndexPython
import itk.itkOffsetPython
import itk.itkSizePython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkRGBPixelPython
import itk.itkRGBAPixelPython
import itk.itkImageToImageFilterBPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkImageToImageFilterCommonPython
import itk.itkImageToImageFilterAPython

def itkCheckerBoardImageFilterICF2_New():
    return itkCheckerBoardImageFilterICF2.New()

class itkCheckerBoardImageFilterICF2(itk.itkImageToImageFilterBPython.itkImageToImageFilterICF2ICF2):
    r"""Proxy of C++ itkCheckerBoardImageFilterICF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkCheckerBoardImageFilterICF2_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkCheckerBoardImageFilterICF2_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICF2_Clone(self)

    def SetInput1(self, image1):
        r"""
        SetInput1(self, image1)

        Parameters
        ----------
        image1: itkImageCF2 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICF2_SetInput1(self, image1)

    def SetInput2(self, image2):
        r"""
        SetInput2(self, image2)

        Parameters
        ----------
        image2: itkImageCF2 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICF2_SetInput2(self, image2)

    def SetCheckerPattern(self, _arg):
        r"""
        SetCheckerPattern(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI2

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICF2_SetCheckerPattern(self, _arg)

    def GetCheckerPattern(self):
        r"""GetCheckerPattern(self) -> itkFixedArrayUI2"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICF2_GetCheckerPattern(self)
    __swig_destroy__ = _itkCheckerBoardImageFilterPython.delete_itkCheckerBoardImageFilterICF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkCheckerBoardImageFilterICF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkCheckerBoardImageFilterICF2

        Create a new object of the class itkCheckerBoardImageFilterICF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkCheckerBoardImageFilterICF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkCheckerBoardImageFilterICF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkCheckerBoardImageFilterICF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkCheckerBoardImageFilterICF2 in _itkCheckerBoardImageFilterPython:
_itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICF2_swigregister(itkCheckerBoardImageFilterICF2)

def itkCheckerBoardImageFilterICF3_New():
    return itkCheckerBoardImageFilterICF3.New()

class itkCheckerBoardImageFilterICF3(itk.itkImageToImageFilterBPython.itkImageToImageFilterICF3ICF3):
    r"""Proxy of C++ itkCheckerBoardImageFilterICF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkCheckerBoardImageFilterICF3_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkCheckerBoardImageFilterICF3_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICF3_Clone(self)

    def SetInput1(self, image1):
        r"""
        SetInput1(self, image1)

        Parameters
        ----------
        image1: itkImageCF3 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICF3_SetInput1(self, image1)

    def SetInput2(self, image2):
        r"""
        SetInput2(self, image2)

        Parameters
        ----------
        image2: itkImageCF3 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICF3_SetInput2(self, image2)

    def SetCheckerPattern(self, _arg):
        r"""
        SetCheckerPattern(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI3

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICF3_SetCheckerPattern(self, _arg)

    def GetCheckerPattern(self):
        r"""GetCheckerPattern(self) -> itkFixedArrayUI3"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICF3_GetCheckerPattern(self)
    __swig_destroy__ = _itkCheckerBoardImageFilterPython.delete_itkCheckerBoardImageFilterICF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkCheckerBoardImageFilterICF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkCheckerBoardImageFilterICF3

        Create a new object of the class itkCheckerBoardImageFilterICF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkCheckerBoardImageFilterICF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkCheckerBoardImageFilterICF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkCheckerBoardImageFilterICF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkCheckerBoardImageFilterICF3 in _itkCheckerBoardImageFilterPython:
_itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICF3_swigregister(itkCheckerBoardImageFilterICF3)

def itkCheckerBoardImageFilterICVF22_New():
    return itkCheckerBoardImageFilterICVF22.New()

class itkCheckerBoardImageFilterICVF22(itk.itkImageToImageFilterAPython.itkImageToImageFilterICVF22ICVF22):
    r"""Proxy of C++ itkCheckerBoardImageFilterICVF22 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkCheckerBoardImageFilterICVF22_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF22___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkCheckerBoardImageFilterICVF22_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF22_Clone(self)

    def SetInput1(self, image1):
        r"""
        SetInput1(self, image1)

        Parameters
        ----------
        image1: itkImageCVF22 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF22_SetInput1(self, image1)

    def SetInput2(self, image2):
        r"""
        SetInput2(self, image2)

        Parameters
        ----------
        image2: itkImageCVF22 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF22_SetInput2(self, image2)

    def SetCheckerPattern(self, _arg):
        r"""
        SetCheckerPattern(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI2

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF22_SetCheckerPattern(self, _arg)

    def GetCheckerPattern(self):
        r"""GetCheckerPattern(self) -> itkFixedArrayUI2"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF22_GetCheckerPattern(self)
    __swig_destroy__ = _itkCheckerBoardImageFilterPython.delete_itkCheckerBoardImageFilterICVF22

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkCheckerBoardImageFilterICVF22

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF22_cast(obj)

    def New(*args, **kargs):
        """New() -> itkCheckerBoardImageFilterICVF22

        Create a new object of the class itkCheckerBoardImageFilterICVF22 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkCheckerBoardImageFilterICVF22.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkCheckerBoardImageFilterICVF22.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkCheckerBoardImageFilterICVF22.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkCheckerBoardImageFilterICVF22 in _itkCheckerBoardImageFilterPython:
_itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF22_swigregister(itkCheckerBoardImageFilterICVF22)

def itkCheckerBoardImageFilterICVF23_New():
    return itkCheckerBoardImageFilterICVF23.New()

class itkCheckerBoardImageFilterICVF23(itk.itkImageToImageFilterAPython.itkImageToImageFilterICVF23ICVF23):
    r"""Proxy of C++ itkCheckerBoardImageFilterICVF23 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkCheckerBoardImageFilterICVF23_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF23___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkCheckerBoardImageFilterICVF23_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF23_Clone(self)

    def SetInput1(self, image1):
        r"""
        SetInput1(self, image1)

        Parameters
        ----------
        image1: itkImageCVF23 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF23_SetInput1(self, image1)

    def SetInput2(self, image2):
        r"""
        SetInput2(self, image2)

        Parameters
        ----------
        image2: itkImageCVF23 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF23_SetInput2(self, image2)

    def SetCheckerPattern(self, _arg):
        r"""
        SetCheckerPattern(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI3

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF23_SetCheckerPattern(self, _arg)

    def GetCheckerPattern(self):
        r"""GetCheckerPattern(self) -> itkFixedArrayUI3"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF23_GetCheckerPattern(self)
    __swig_destroy__ = _itkCheckerBoardImageFilterPython.delete_itkCheckerBoardImageFilterICVF23

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkCheckerBoardImageFilterICVF23

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF23_cast(obj)

    def New(*args, **kargs):
        """New() -> itkCheckerBoardImageFilterICVF23

        Create a new object of the class itkCheckerBoardImageFilterICVF23 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkCheckerBoardImageFilterICVF23.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkCheckerBoardImageFilterICVF23.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkCheckerBoardImageFilterICVF23.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkCheckerBoardImageFilterICVF23 in _itkCheckerBoardImageFilterPython:
_itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF23_swigregister(itkCheckerBoardImageFilterICVF23)

def itkCheckerBoardImageFilterICVF32_New():
    return itkCheckerBoardImageFilterICVF32.New()

class itkCheckerBoardImageFilterICVF32(itk.itkImageToImageFilterAPython.itkImageToImageFilterICVF32ICVF32):
    r"""Proxy of C++ itkCheckerBoardImageFilterICVF32 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkCheckerBoardImageFilterICVF32_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF32___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkCheckerBoardImageFilterICVF32_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF32_Clone(self)

    def SetInput1(self, image1):
        r"""
        SetInput1(self, image1)

        Parameters
        ----------
        image1: itkImageCVF32 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF32_SetInput1(self, image1)

    def SetInput2(self, image2):
        r"""
        SetInput2(self, image2)

        Parameters
        ----------
        image2: itkImageCVF32 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF32_SetInput2(self, image2)

    def SetCheckerPattern(self, _arg):
        r"""
        SetCheckerPattern(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI2

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF32_SetCheckerPattern(self, _arg)

    def GetCheckerPattern(self):
        r"""GetCheckerPattern(self) -> itkFixedArrayUI2"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF32_GetCheckerPattern(self)
    __swig_destroy__ = _itkCheckerBoardImageFilterPython.delete_itkCheckerBoardImageFilterICVF32

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkCheckerBoardImageFilterICVF32

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF32_cast(obj)

    def New(*args, **kargs):
        """New() -> itkCheckerBoardImageFilterICVF32

        Create a new object of the class itkCheckerBoardImageFilterICVF32 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkCheckerBoardImageFilterICVF32.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkCheckerBoardImageFilterICVF32.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkCheckerBoardImageFilterICVF32.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkCheckerBoardImageFilterICVF32 in _itkCheckerBoardImageFilterPython:
_itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF32_swigregister(itkCheckerBoardImageFilterICVF32)

def itkCheckerBoardImageFilterICVF33_New():
    return itkCheckerBoardImageFilterICVF33.New()

class itkCheckerBoardImageFilterICVF33(itk.itkImageToImageFilterAPython.itkImageToImageFilterICVF33ICVF33):
    r"""Proxy of C++ itkCheckerBoardImageFilterICVF33 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkCheckerBoardImageFilterICVF33_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF33___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkCheckerBoardImageFilterICVF33_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF33_Clone(self)

    def SetInput1(self, image1):
        r"""
        SetInput1(self, image1)

        Parameters
        ----------
        image1: itkImageCVF33 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF33_SetInput1(self, image1)

    def SetInput2(self, image2):
        r"""
        SetInput2(self, image2)

        Parameters
        ----------
        image2: itkImageCVF33 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF33_SetInput2(self, image2)

    def SetCheckerPattern(self, _arg):
        r"""
        SetCheckerPattern(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI3

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF33_SetCheckerPattern(self, _arg)

    def GetCheckerPattern(self):
        r"""GetCheckerPattern(self) -> itkFixedArrayUI3"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF33_GetCheckerPattern(self)
    __swig_destroy__ = _itkCheckerBoardImageFilterPython.delete_itkCheckerBoardImageFilterICVF33

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkCheckerBoardImageFilterICVF33

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF33_cast(obj)

    def New(*args, **kargs):
        """New() -> itkCheckerBoardImageFilterICVF33

        Create a new object of the class itkCheckerBoardImageFilterICVF33 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkCheckerBoardImageFilterICVF33.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkCheckerBoardImageFilterICVF33.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkCheckerBoardImageFilterICVF33.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkCheckerBoardImageFilterICVF33 in _itkCheckerBoardImageFilterPython:
_itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF33_swigregister(itkCheckerBoardImageFilterICVF33)

def itkCheckerBoardImageFilterICVF42_New():
    return itkCheckerBoardImageFilterICVF42.New()

class itkCheckerBoardImageFilterICVF42(itk.itkImageToImageFilterAPython.itkImageToImageFilterICVF42ICVF42):
    r"""Proxy of C++ itkCheckerBoardImageFilterICVF42 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkCheckerBoardImageFilterICVF42_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF42___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkCheckerBoardImageFilterICVF42_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF42_Clone(self)

    def SetInput1(self, image1):
        r"""
        SetInput1(self, image1)

        Parameters
        ----------
        image1: itkImageCVF42 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF42_SetInput1(self, image1)

    def SetInput2(self, image2):
        r"""
        SetInput2(self, image2)

        Parameters
        ----------
        image2: itkImageCVF42 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF42_SetInput2(self, image2)

    def SetCheckerPattern(self, _arg):
        r"""
        SetCheckerPattern(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI2

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF42_SetCheckerPattern(self, _arg)

    def GetCheckerPattern(self):
        r"""GetCheckerPattern(self) -> itkFixedArrayUI2"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF42_GetCheckerPattern(self)
    __swig_destroy__ = _itkCheckerBoardImageFilterPython.delete_itkCheckerBoardImageFilterICVF42

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkCheckerBoardImageFilterICVF42

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF42_cast(obj)

    def New(*args, **kargs):
        """New() -> itkCheckerBoardImageFilterICVF42

        Create a new object of the class itkCheckerBoardImageFilterICVF42 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkCheckerBoardImageFilterICVF42.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkCheckerBoardImageFilterICVF42.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkCheckerBoardImageFilterICVF42.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkCheckerBoardImageFilterICVF42 in _itkCheckerBoardImageFilterPython:
_itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF42_swigregister(itkCheckerBoardImageFilterICVF42)

def itkCheckerBoardImageFilterICVF43_New():
    return itkCheckerBoardImageFilterICVF43.New()

class itkCheckerBoardImageFilterICVF43(itk.itkImageToImageFilterAPython.itkImageToImageFilterICVF43ICVF43):
    r"""Proxy of C++ itkCheckerBoardImageFilterICVF43 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkCheckerBoardImageFilterICVF43_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF43___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkCheckerBoardImageFilterICVF43_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF43_Clone(self)

    def SetInput1(self, image1):
        r"""
        SetInput1(self, image1)

        Parameters
        ----------
        image1: itkImageCVF43 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF43_SetInput1(self, image1)

    def SetInput2(self, image2):
        r"""
        SetInput2(self, image2)

        Parameters
        ----------
        image2: itkImageCVF43 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF43_SetInput2(self, image2)

    def SetCheckerPattern(self, _arg):
        r"""
        SetCheckerPattern(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI3

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF43_SetCheckerPattern(self, _arg)

    def GetCheckerPattern(self):
        r"""GetCheckerPattern(self) -> itkFixedArrayUI3"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF43_GetCheckerPattern(self)
    __swig_destroy__ = _itkCheckerBoardImageFilterPython.delete_itkCheckerBoardImageFilterICVF43

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkCheckerBoardImageFilterICVF43

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF43_cast(obj)

    def New(*args, **kargs):
        """New() -> itkCheckerBoardImageFilterICVF43

        Create a new object of the class itkCheckerBoardImageFilterICVF43 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkCheckerBoardImageFilterICVF43.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkCheckerBoardImageFilterICVF43.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkCheckerBoardImageFilterICVF43.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkCheckerBoardImageFilterICVF43 in _itkCheckerBoardImageFilterPython:
_itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterICVF43_swigregister(itkCheckerBoardImageFilterICVF43)

def itkCheckerBoardImageFilterIF2_New():
    return itkCheckerBoardImageFilterIF2.New()

class itkCheckerBoardImageFilterIF2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF2IF2):
    r"""Proxy of C++ itkCheckerBoardImageFilterIF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkCheckerBoardImageFilterIF2_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkCheckerBoardImageFilterIF2_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIF2_Clone(self)

    def SetInput1(self, image1):
        r"""
        SetInput1(self, image1)

        Parameters
        ----------
        image1: itkImageF2 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIF2_SetInput1(self, image1)

    def SetInput2(self, image2):
        r"""
        SetInput2(self, image2)

        Parameters
        ----------
        image2: itkImageF2 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIF2_SetInput2(self, image2)

    def SetCheckerPattern(self, _arg):
        r"""
        SetCheckerPattern(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI2

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIF2_SetCheckerPattern(self, _arg)

    def GetCheckerPattern(self):
        r"""GetCheckerPattern(self) -> itkFixedArrayUI2"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIF2_GetCheckerPattern(self)
    __swig_destroy__ = _itkCheckerBoardImageFilterPython.delete_itkCheckerBoardImageFilterIF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkCheckerBoardImageFilterIF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkCheckerBoardImageFilterIF2

        Create a new object of the class itkCheckerBoardImageFilterIF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkCheckerBoardImageFilterIF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkCheckerBoardImageFilterIF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkCheckerBoardImageFilterIF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkCheckerBoardImageFilterIF2 in _itkCheckerBoardImageFilterPython:
_itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIF2_swigregister(itkCheckerBoardImageFilterIF2)

def itkCheckerBoardImageFilterIF3_New():
    return itkCheckerBoardImageFilterIF3.New()

class itkCheckerBoardImageFilterIF3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF3IF3):
    r"""Proxy of C++ itkCheckerBoardImageFilterIF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkCheckerBoardImageFilterIF3_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkCheckerBoardImageFilterIF3_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIF3_Clone(self)

    def SetInput1(self, image1):
        r"""
        SetInput1(self, image1)

        Parameters
        ----------
        image1: itkImageF3 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIF3_SetInput1(self, image1)

    def SetInput2(self, image2):
        r"""
        SetInput2(self, image2)

        Parameters
        ----------
        image2: itkImageF3 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIF3_SetInput2(self, image2)

    def SetCheckerPattern(self, _arg):
        r"""
        SetCheckerPattern(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI3

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIF3_SetCheckerPattern(self, _arg)

    def GetCheckerPattern(self):
        r"""GetCheckerPattern(self) -> itkFixedArrayUI3"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIF3_GetCheckerPattern(self)
    __swig_destroy__ = _itkCheckerBoardImageFilterPython.delete_itkCheckerBoardImageFilterIF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkCheckerBoardImageFilterIF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkCheckerBoardImageFilterIF3

        Create a new object of the class itkCheckerBoardImageFilterIF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkCheckerBoardImageFilterIF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkCheckerBoardImageFilterIF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkCheckerBoardImageFilterIF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkCheckerBoardImageFilterIF3 in _itkCheckerBoardImageFilterPython:
_itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIF3_swigregister(itkCheckerBoardImageFilterIF3)

def itkCheckerBoardImageFilterIRGBAUC2_New():
    return itkCheckerBoardImageFilterIRGBAUC2.New()

class itkCheckerBoardImageFilterIRGBAUC2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIRGBAUC2IRGBAUC2):
    r"""Proxy of C++ itkCheckerBoardImageFilterIRGBAUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkCheckerBoardImageFilterIRGBAUC2_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIRGBAUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkCheckerBoardImageFilterIRGBAUC2_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIRGBAUC2_Clone(self)

    def SetInput1(self, image1):
        r"""
        SetInput1(self, image1)

        Parameters
        ----------
        image1: itkImageRGBAUC2 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIRGBAUC2_SetInput1(self, image1)

    def SetInput2(self, image2):
        r"""
        SetInput2(self, image2)

        Parameters
        ----------
        image2: itkImageRGBAUC2 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIRGBAUC2_SetInput2(self, image2)

    def SetCheckerPattern(self, _arg):
        r"""
        SetCheckerPattern(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI2

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIRGBAUC2_SetCheckerPattern(self, _arg)

    def GetCheckerPattern(self):
        r"""GetCheckerPattern(self) -> itkFixedArrayUI2"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIRGBAUC2_GetCheckerPattern(self)
    __swig_destroy__ = _itkCheckerBoardImageFilterPython.delete_itkCheckerBoardImageFilterIRGBAUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkCheckerBoardImageFilterIRGBAUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIRGBAUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkCheckerBoardImageFilterIRGBAUC2

        Create a new object of the class itkCheckerBoardImageFilterIRGBAUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkCheckerBoardImageFilterIRGBAUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkCheckerBoardImageFilterIRGBAUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkCheckerBoardImageFilterIRGBAUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkCheckerBoardImageFilterIRGBAUC2 in _itkCheckerBoardImageFilterPython:
_itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIRGBAUC2_swigregister(itkCheckerBoardImageFilterIRGBAUC2)

def itkCheckerBoardImageFilterIRGBAUC3_New():
    return itkCheckerBoardImageFilterIRGBAUC3.New()

class itkCheckerBoardImageFilterIRGBAUC3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIRGBAUC3IRGBAUC3):
    r"""Proxy of C++ itkCheckerBoardImageFilterIRGBAUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkCheckerBoardImageFilterIRGBAUC3_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIRGBAUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkCheckerBoardImageFilterIRGBAUC3_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIRGBAUC3_Clone(self)

    def SetInput1(self, image1):
        r"""
        SetInput1(self, image1)

        Parameters
        ----------
        image1: itkImageRGBAUC3 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIRGBAUC3_SetInput1(self, image1)

    def SetInput2(self, image2):
        r"""
        SetInput2(self, image2)

        Parameters
        ----------
        image2: itkImageRGBAUC3 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIRGBAUC3_SetInput2(self, image2)

    def SetCheckerPattern(self, _arg):
        r"""
        SetCheckerPattern(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI3

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIRGBAUC3_SetCheckerPattern(self, _arg)

    def GetCheckerPattern(self):
        r"""GetCheckerPattern(self) -> itkFixedArrayUI3"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIRGBAUC3_GetCheckerPattern(self)
    __swig_destroy__ = _itkCheckerBoardImageFilterPython.delete_itkCheckerBoardImageFilterIRGBAUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkCheckerBoardImageFilterIRGBAUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIRGBAUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkCheckerBoardImageFilterIRGBAUC3

        Create a new object of the class itkCheckerBoardImageFilterIRGBAUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkCheckerBoardImageFilterIRGBAUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkCheckerBoardImageFilterIRGBAUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkCheckerBoardImageFilterIRGBAUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkCheckerBoardImageFilterIRGBAUC3 in _itkCheckerBoardImageFilterPython:
_itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIRGBAUC3_swigregister(itkCheckerBoardImageFilterIRGBAUC3)

def itkCheckerBoardImageFilterIRGBUC2_New():
    return itkCheckerBoardImageFilterIRGBUC2.New()

class itkCheckerBoardImageFilterIRGBUC2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIRGBUC2IRGBUC2):
    r"""Proxy of C++ itkCheckerBoardImageFilterIRGBUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkCheckerBoardImageFilterIRGBUC2_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIRGBUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkCheckerBoardImageFilterIRGBUC2_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIRGBUC2_Clone(self)

    def SetInput1(self, image1):
        r"""
        SetInput1(self, image1)

        Parameters
        ----------
        image1: itkImageRGBUC2 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIRGBUC2_SetInput1(self, image1)

    def SetInput2(self, image2):
        r"""
        SetInput2(self, image2)

        Parameters
        ----------
        image2: itkImageRGBUC2 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIRGBUC2_SetInput2(self, image2)

    def SetCheckerPattern(self, _arg):
        r"""
        SetCheckerPattern(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI2

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIRGBUC2_SetCheckerPattern(self, _arg)

    def GetCheckerPattern(self):
        r"""GetCheckerPattern(self) -> itkFixedArrayUI2"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIRGBUC2_GetCheckerPattern(self)
    __swig_destroy__ = _itkCheckerBoardImageFilterPython.delete_itkCheckerBoardImageFilterIRGBUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkCheckerBoardImageFilterIRGBUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIRGBUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkCheckerBoardImageFilterIRGBUC2

        Create a new object of the class itkCheckerBoardImageFilterIRGBUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkCheckerBoardImageFilterIRGBUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkCheckerBoardImageFilterIRGBUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkCheckerBoardImageFilterIRGBUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkCheckerBoardImageFilterIRGBUC2 in _itkCheckerBoardImageFilterPython:
_itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIRGBUC2_swigregister(itkCheckerBoardImageFilterIRGBUC2)

def itkCheckerBoardImageFilterIRGBUC3_New():
    return itkCheckerBoardImageFilterIRGBUC3.New()

class itkCheckerBoardImageFilterIRGBUC3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIRGBUC3IRGBUC3):
    r"""Proxy of C++ itkCheckerBoardImageFilterIRGBUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkCheckerBoardImageFilterIRGBUC3_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIRGBUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkCheckerBoardImageFilterIRGBUC3_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIRGBUC3_Clone(self)

    def SetInput1(self, image1):
        r"""
        SetInput1(self, image1)

        Parameters
        ----------
        image1: itkImageRGBUC3 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIRGBUC3_SetInput1(self, image1)

    def SetInput2(self, image2):
        r"""
        SetInput2(self, image2)

        Parameters
        ----------
        image2: itkImageRGBUC3 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIRGBUC3_SetInput2(self, image2)

    def SetCheckerPattern(self, _arg):
        r"""
        SetCheckerPattern(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI3

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIRGBUC3_SetCheckerPattern(self, _arg)

    def GetCheckerPattern(self):
        r"""GetCheckerPattern(self) -> itkFixedArrayUI3"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIRGBUC3_GetCheckerPattern(self)
    __swig_destroy__ = _itkCheckerBoardImageFilterPython.delete_itkCheckerBoardImageFilterIRGBUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkCheckerBoardImageFilterIRGBUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIRGBUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkCheckerBoardImageFilterIRGBUC3

        Create a new object of the class itkCheckerBoardImageFilterIRGBUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkCheckerBoardImageFilterIRGBUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkCheckerBoardImageFilterIRGBUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkCheckerBoardImageFilterIRGBUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkCheckerBoardImageFilterIRGBUC3 in _itkCheckerBoardImageFilterPython:
_itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIRGBUC3_swigregister(itkCheckerBoardImageFilterIRGBUC3)

def itkCheckerBoardImageFilterISS2_New():
    return itkCheckerBoardImageFilterISS2.New()

class itkCheckerBoardImageFilterISS2(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS2ISS2):
    r"""Proxy of C++ itkCheckerBoardImageFilterISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkCheckerBoardImageFilterISS2_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkCheckerBoardImageFilterISS2_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterISS2_Clone(self)

    def SetInput1(self, image1):
        r"""
        SetInput1(self, image1)

        Parameters
        ----------
        image1: itkImageSS2 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterISS2_SetInput1(self, image1)

    def SetInput2(self, image2):
        r"""
        SetInput2(self, image2)

        Parameters
        ----------
        image2: itkImageSS2 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterISS2_SetInput2(self, image2)

    def SetCheckerPattern(self, _arg):
        r"""
        SetCheckerPattern(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI2

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterISS2_SetCheckerPattern(self, _arg)

    def GetCheckerPattern(self):
        r"""GetCheckerPattern(self) -> itkFixedArrayUI2"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterISS2_GetCheckerPattern(self)
    __swig_destroy__ = _itkCheckerBoardImageFilterPython.delete_itkCheckerBoardImageFilterISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkCheckerBoardImageFilterISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkCheckerBoardImageFilterISS2

        Create a new object of the class itkCheckerBoardImageFilterISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkCheckerBoardImageFilterISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkCheckerBoardImageFilterISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkCheckerBoardImageFilterISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkCheckerBoardImageFilterISS2 in _itkCheckerBoardImageFilterPython:
_itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterISS2_swigregister(itkCheckerBoardImageFilterISS2)

def itkCheckerBoardImageFilterISS3_New():
    return itkCheckerBoardImageFilterISS3.New()

class itkCheckerBoardImageFilterISS3(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS3ISS3):
    r"""Proxy of C++ itkCheckerBoardImageFilterISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkCheckerBoardImageFilterISS3_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkCheckerBoardImageFilterISS3_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterISS3_Clone(self)

    def SetInput1(self, image1):
        r"""
        SetInput1(self, image1)

        Parameters
        ----------
        image1: itkImageSS3 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterISS3_SetInput1(self, image1)

    def SetInput2(self, image2):
        r"""
        SetInput2(self, image2)

        Parameters
        ----------
        image2: itkImageSS3 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterISS3_SetInput2(self, image2)

    def SetCheckerPattern(self, _arg):
        r"""
        SetCheckerPattern(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI3

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterISS3_SetCheckerPattern(self, _arg)

    def GetCheckerPattern(self):
        r"""GetCheckerPattern(self) -> itkFixedArrayUI3"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterISS3_GetCheckerPattern(self)
    __swig_destroy__ = _itkCheckerBoardImageFilterPython.delete_itkCheckerBoardImageFilterISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkCheckerBoardImageFilterISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkCheckerBoardImageFilterISS3

        Create a new object of the class itkCheckerBoardImageFilterISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkCheckerBoardImageFilterISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkCheckerBoardImageFilterISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkCheckerBoardImageFilterISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkCheckerBoardImageFilterISS3 in _itkCheckerBoardImageFilterPython:
_itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterISS3_swigregister(itkCheckerBoardImageFilterISS3)

def itkCheckerBoardImageFilterIUC2_New():
    return itkCheckerBoardImageFilterIUC2.New()

class itkCheckerBoardImageFilterIUC2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC2IUC2):
    r"""Proxy of C++ itkCheckerBoardImageFilterIUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkCheckerBoardImageFilterIUC2_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkCheckerBoardImageFilterIUC2_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIUC2_Clone(self)

    def SetInput1(self, image1):
        r"""
        SetInput1(self, image1)

        Parameters
        ----------
        image1: itkImageUC2 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIUC2_SetInput1(self, image1)

    def SetInput2(self, image2):
        r"""
        SetInput2(self, image2)

        Parameters
        ----------
        image2: itkImageUC2 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIUC2_SetInput2(self, image2)

    def SetCheckerPattern(self, _arg):
        r"""
        SetCheckerPattern(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI2

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIUC2_SetCheckerPattern(self, _arg)

    def GetCheckerPattern(self):
        r"""GetCheckerPattern(self) -> itkFixedArrayUI2"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIUC2_GetCheckerPattern(self)
    __swig_destroy__ = _itkCheckerBoardImageFilterPython.delete_itkCheckerBoardImageFilterIUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkCheckerBoardImageFilterIUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkCheckerBoardImageFilterIUC2

        Create a new object of the class itkCheckerBoardImageFilterIUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkCheckerBoardImageFilterIUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkCheckerBoardImageFilterIUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkCheckerBoardImageFilterIUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkCheckerBoardImageFilterIUC2 in _itkCheckerBoardImageFilterPython:
_itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIUC2_swigregister(itkCheckerBoardImageFilterIUC2)

def itkCheckerBoardImageFilterIUC3_New():
    return itkCheckerBoardImageFilterIUC3.New()

class itkCheckerBoardImageFilterIUC3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC3IUC3):
    r"""Proxy of C++ itkCheckerBoardImageFilterIUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkCheckerBoardImageFilterIUC3_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkCheckerBoardImageFilterIUC3_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIUC3_Clone(self)

    def SetInput1(self, image1):
        r"""
        SetInput1(self, image1)

        Parameters
        ----------
        image1: itkImageUC3 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIUC3_SetInput1(self, image1)

    def SetInput2(self, image2):
        r"""
        SetInput2(self, image2)

        Parameters
        ----------
        image2: itkImageUC3 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIUC3_SetInput2(self, image2)

    def SetCheckerPattern(self, _arg):
        r"""
        SetCheckerPattern(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI3

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIUC3_SetCheckerPattern(self, _arg)

    def GetCheckerPattern(self):
        r"""GetCheckerPattern(self) -> itkFixedArrayUI3"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIUC3_GetCheckerPattern(self)
    __swig_destroy__ = _itkCheckerBoardImageFilterPython.delete_itkCheckerBoardImageFilterIUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkCheckerBoardImageFilterIUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkCheckerBoardImageFilterIUC3

        Create a new object of the class itkCheckerBoardImageFilterIUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkCheckerBoardImageFilterIUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkCheckerBoardImageFilterIUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkCheckerBoardImageFilterIUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkCheckerBoardImageFilterIUC3 in _itkCheckerBoardImageFilterPython:
_itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIUC3_swigregister(itkCheckerBoardImageFilterIUC3)

def itkCheckerBoardImageFilterIVF22_New():
    return itkCheckerBoardImageFilterIVF22.New()

class itkCheckerBoardImageFilterIVF22(itk.itkImageToImageFilterAPython.itkImageToImageFilterIVF22IVF22):
    r"""Proxy of C++ itkCheckerBoardImageFilterIVF22 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkCheckerBoardImageFilterIVF22_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF22___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkCheckerBoardImageFilterIVF22_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF22_Clone(self)

    def SetInput1(self, image1):
        r"""
        SetInput1(self, image1)

        Parameters
        ----------
        image1: itkImageVF22 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF22_SetInput1(self, image1)

    def SetInput2(self, image2):
        r"""
        SetInput2(self, image2)

        Parameters
        ----------
        image2: itkImageVF22 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF22_SetInput2(self, image2)

    def SetCheckerPattern(self, _arg):
        r"""
        SetCheckerPattern(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI2

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF22_SetCheckerPattern(self, _arg)

    def GetCheckerPattern(self):
        r"""GetCheckerPattern(self) -> itkFixedArrayUI2"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF22_GetCheckerPattern(self)
    __swig_destroy__ = _itkCheckerBoardImageFilterPython.delete_itkCheckerBoardImageFilterIVF22

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkCheckerBoardImageFilterIVF22

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF22_cast(obj)

    def New(*args, **kargs):
        """New() -> itkCheckerBoardImageFilterIVF22

        Create a new object of the class itkCheckerBoardImageFilterIVF22 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkCheckerBoardImageFilterIVF22.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkCheckerBoardImageFilterIVF22.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkCheckerBoardImageFilterIVF22.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkCheckerBoardImageFilterIVF22 in _itkCheckerBoardImageFilterPython:
_itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF22_swigregister(itkCheckerBoardImageFilterIVF22)

def itkCheckerBoardImageFilterIVF23_New():
    return itkCheckerBoardImageFilterIVF23.New()

class itkCheckerBoardImageFilterIVF23(itk.itkImageToImageFilterAPython.itkImageToImageFilterIVF23IVF23):
    r"""Proxy of C++ itkCheckerBoardImageFilterIVF23 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkCheckerBoardImageFilterIVF23_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF23___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkCheckerBoardImageFilterIVF23_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF23_Clone(self)

    def SetInput1(self, image1):
        r"""
        SetInput1(self, image1)

        Parameters
        ----------
        image1: itkImageVF23 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF23_SetInput1(self, image1)

    def SetInput2(self, image2):
        r"""
        SetInput2(self, image2)

        Parameters
        ----------
        image2: itkImageVF23 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF23_SetInput2(self, image2)

    def SetCheckerPattern(self, _arg):
        r"""
        SetCheckerPattern(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI3

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF23_SetCheckerPattern(self, _arg)

    def GetCheckerPattern(self):
        r"""GetCheckerPattern(self) -> itkFixedArrayUI3"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF23_GetCheckerPattern(self)
    __swig_destroy__ = _itkCheckerBoardImageFilterPython.delete_itkCheckerBoardImageFilterIVF23

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkCheckerBoardImageFilterIVF23

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF23_cast(obj)

    def New(*args, **kargs):
        """New() -> itkCheckerBoardImageFilterIVF23

        Create a new object of the class itkCheckerBoardImageFilterIVF23 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkCheckerBoardImageFilterIVF23.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkCheckerBoardImageFilterIVF23.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkCheckerBoardImageFilterIVF23.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkCheckerBoardImageFilterIVF23 in _itkCheckerBoardImageFilterPython:
_itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF23_swigregister(itkCheckerBoardImageFilterIVF23)

def itkCheckerBoardImageFilterIVF32_New():
    return itkCheckerBoardImageFilterIVF32.New()

class itkCheckerBoardImageFilterIVF32(itk.itkImageToImageFilterAPython.itkImageToImageFilterIVF32IVF32):
    r"""Proxy of C++ itkCheckerBoardImageFilterIVF32 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkCheckerBoardImageFilterIVF32_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF32___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkCheckerBoardImageFilterIVF32_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF32_Clone(self)

    def SetInput1(self, image1):
        r"""
        SetInput1(self, image1)

        Parameters
        ----------
        image1: itkImageVF32 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF32_SetInput1(self, image1)

    def SetInput2(self, image2):
        r"""
        SetInput2(self, image2)

        Parameters
        ----------
        image2: itkImageVF32 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF32_SetInput2(self, image2)

    def SetCheckerPattern(self, _arg):
        r"""
        SetCheckerPattern(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI2

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF32_SetCheckerPattern(self, _arg)

    def GetCheckerPattern(self):
        r"""GetCheckerPattern(self) -> itkFixedArrayUI2"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF32_GetCheckerPattern(self)
    __swig_destroy__ = _itkCheckerBoardImageFilterPython.delete_itkCheckerBoardImageFilterIVF32

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkCheckerBoardImageFilterIVF32

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF32_cast(obj)

    def New(*args, **kargs):
        """New() -> itkCheckerBoardImageFilterIVF32

        Create a new object of the class itkCheckerBoardImageFilterIVF32 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkCheckerBoardImageFilterIVF32.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkCheckerBoardImageFilterIVF32.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkCheckerBoardImageFilterIVF32.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkCheckerBoardImageFilterIVF32 in _itkCheckerBoardImageFilterPython:
_itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF32_swigregister(itkCheckerBoardImageFilterIVF32)

def itkCheckerBoardImageFilterIVF33_New():
    return itkCheckerBoardImageFilterIVF33.New()

class itkCheckerBoardImageFilterIVF33(itk.itkImageToImageFilterAPython.itkImageToImageFilterIVF33IVF33):
    r"""Proxy of C++ itkCheckerBoardImageFilterIVF33 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkCheckerBoardImageFilterIVF33_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF33___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkCheckerBoardImageFilterIVF33_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF33_Clone(self)

    def SetInput1(self, image1):
        r"""
        SetInput1(self, image1)

        Parameters
        ----------
        image1: itkImageVF33 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF33_SetInput1(self, image1)

    def SetInput2(self, image2):
        r"""
        SetInput2(self, image2)

        Parameters
        ----------
        image2: itkImageVF33 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF33_SetInput2(self, image2)

    def SetCheckerPattern(self, _arg):
        r"""
        SetCheckerPattern(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI3

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF33_SetCheckerPattern(self, _arg)

    def GetCheckerPattern(self):
        r"""GetCheckerPattern(self) -> itkFixedArrayUI3"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF33_GetCheckerPattern(self)
    __swig_destroy__ = _itkCheckerBoardImageFilterPython.delete_itkCheckerBoardImageFilterIVF33

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkCheckerBoardImageFilterIVF33

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF33_cast(obj)

    def New(*args, **kargs):
        """New() -> itkCheckerBoardImageFilterIVF33

        Create a new object of the class itkCheckerBoardImageFilterIVF33 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkCheckerBoardImageFilterIVF33.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkCheckerBoardImageFilterIVF33.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkCheckerBoardImageFilterIVF33.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkCheckerBoardImageFilterIVF33 in _itkCheckerBoardImageFilterPython:
_itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF33_swigregister(itkCheckerBoardImageFilterIVF33)

def itkCheckerBoardImageFilterIVF42_New():
    return itkCheckerBoardImageFilterIVF42.New()

class itkCheckerBoardImageFilterIVF42(itk.itkImageToImageFilterAPython.itkImageToImageFilterIVF42IVF42):
    r"""Proxy of C++ itkCheckerBoardImageFilterIVF42 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkCheckerBoardImageFilterIVF42_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF42___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkCheckerBoardImageFilterIVF42_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF42_Clone(self)

    def SetInput1(self, image1):
        r"""
        SetInput1(self, image1)

        Parameters
        ----------
        image1: itkImageVF42 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF42_SetInput1(self, image1)

    def SetInput2(self, image2):
        r"""
        SetInput2(self, image2)

        Parameters
        ----------
        image2: itkImageVF42 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF42_SetInput2(self, image2)

    def SetCheckerPattern(self, _arg):
        r"""
        SetCheckerPattern(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI2

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF42_SetCheckerPattern(self, _arg)

    def GetCheckerPattern(self):
        r"""GetCheckerPattern(self) -> itkFixedArrayUI2"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF42_GetCheckerPattern(self)
    __swig_destroy__ = _itkCheckerBoardImageFilterPython.delete_itkCheckerBoardImageFilterIVF42

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkCheckerBoardImageFilterIVF42

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF42_cast(obj)

    def New(*args, **kargs):
        """New() -> itkCheckerBoardImageFilterIVF42

        Create a new object of the class itkCheckerBoardImageFilterIVF42 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkCheckerBoardImageFilterIVF42.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkCheckerBoardImageFilterIVF42.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkCheckerBoardImageFilterIVF42.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkCheckerBoardImageFilterIVF42 in _itkCheckerBoardImageFilterPython:
_itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF42_swigregister(itkCheckerBoardImageFilterIVF42)

def itkCheckerBoardImageFilterIVF43_New():
    return itkCheckerBoardImageFilterIVF43.New()

class itkCheckerBoardImageFilterIVF43(itk.itkImageToImageFilterAPython.itkImageToImageFilterIVF43IVF43):
    r"""Proxy of C++ itkCheckerBoardImageFilterIVF43 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkCheckerBoardImageFilterIVF43_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF43___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkCheckerBoardImageFilterIVF43_Pointer"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF43_Clone(self)

    def SetInput1(self, image1):
        r"""
        SetInput1(self, image1)

        Parameters
        ----------
        image1: itkImageVF43 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF43_SetInput1(self, image1)

    def SetInput2(self, image2):
        r"""
        SetInput2(self, image2)

        Parameters
        ----------
        image2: itkImageVF43 const *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF43_SetInput2(self, image2)

    def SetCheckerPattern(self, _arg):
        r"""
        SetCheckerPattern(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI3

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF43_SetCheckerPattern(self, _arg)

    def GetCheckerPattern(self):
        r"""GetCheckerPattern(self) -> itkFixedArrayUI3"""
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF43_GetCheckerPattern(self)
    __swig_destroy__ = _itkCheckerBoardImageFilterPython.delete_itkCheckerBoardImageFilterIVF43

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkCheckerBoardImageFilterIVF43

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF43_cast(obj)

    def New(*args, **kargs):
        """New() -> itkCheckerBoardImageFilterIVF43

        Create a new object of the class itkCheckerBoardImageFilterIVF43 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkCheckerBoardImageFilterIVF43.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkCheckerBoardImageFilterIVF43.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkCheckerBoardImageFilterIVF43.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkCheckerBoardImageFilterIVF43 in _itkCheckerBoardImageFilterPython:
_itkCheckerBoardImageFilterPython.itkCheckerBoardImageFilterIVF43_swigregister(itkCheckerBoardImageFilterIVF43)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def checker_board_image_filter(*args: itkt.ImageLike,  checker_pattern: Sequence[int]=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for CheckerBoardImageFilter"""
    import itk

    kwarg_typehints = { 'checker_pattern':checker_pattern }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.CheckerBoardImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def checker_board_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKImageCompare.CheckerBoardImageFilter
    checker_board_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    checker_board_image_filter.__doc__ = filter_object.__doc__



